{% extends "base.html" %}
{% load static %}
{% load i18n %}
{% block content %}
<p><a class="btn btn-default" href="{% url 'pyfb-kamailio:pyfb_kamailio_speeddial_list' %}">SpeedDial Listing</a></p>
<table class="table">
<tr>
<td>ID</td><td>Link</td>
    <td>username</td>
    <td>domain</td>
    <td>sd_username</td>
    <td>sd_domain</td>
    <td>new_uri</td>
    <td>fname</td>
    <td>lname</td>
    <td>description</td>
</tr>
{% for object in object_list %}
<tr>
    <td>{{object.pk}}</td>
    <td><a href="{{object.get_absolute_url}}">{{object}}</a></td>
    <td>{{ object.username }}</td>
    <td>{{ object.domain }}</td>
    <td>{{ object.sd_username }}</td>
    <td>{{ object.sd_domain }}</td>
    <td>{{ object.new_uri }}</td>
    <td>{{ object.fname }}</td>
    <td>{{ object.lname }}</td>
    <td>{{ object.description }}</td>
</tr>
{% endfor %}
</table><a class="btn btn-primary" href="{% url 'pyfb-kamailio:pyfb_kamailio_speeddial_create' %}">Create new SpeedDial</a>
{% endblock %}
