# Generated by Django 2.1.5 on 2019-02-25 17:40

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('pyfb_kamailio', '0003_auto_20190130_1708'),
    ]

    operations = [
        migrations.RenameField(
            model_name='dialog',
            old_name='callee_stock',
            new_name='callee_sock',
        ),
    ]
