{% extends "base.html" %}
{% load static %}
{% load i18n %}
{% block content %}
<p><a class="btn btn-default" href="{% url 'pyfb-kamailio:pyfb_kamailio_rtpengine_list' %}">RtpEngine Listing</a></p>
<table class="table">
<tr>
<td>ID</td><td>Link</td>
    <td>setid</td>
    <td>url</td>
    <td>weight</td>
    <td>disabled</td>
    <td>stamp</td>
</tr>
{% for object in object_list %}
<tr>
    <td>{{object.pk}}</td>
    <td><a href="{{object.get_absolute_url}}">{{object}}</a></td>
    <td>{{ object.setid }}</td>
    <td>{{ object.url }}</td>
    <td>{{ object.weight }}</td>
    <td>{{ object.disabled }}</td>
    <td>{{ object.stamp }}</td>
</tr>
{% endfor %}
</table><a class="btn btn-primary" href="{% url 'pyfb-kamailio:pyfb_kamailio_rtpengine_create' %}">Create new RtpEngine</a>
{% endblock %}
