# Generated by Django 2.1.5 on 2019-05-23 16:47

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('pyfb_kamailio', '0008_auto_20190523_1635'),
    ]

    operations = [
        migrations.AlterField(
            model_name='domain',
            name='last_modified',
            field=models.DateTimeField(auto_now=True, help_text='Date and time when this record was last modified.', verbose_name='last modified'),
        ),
    ]
