{% extends "base.html" %}
{% load static %}
{% load i18n %}
{% block content %}
<p><a class="btn btn-default" href="{% url 'pyfb-kamailio:pyfb_kamailio_acc_list' %}">Acc Listing</a></p>
<table class="table">
<tr>
<td>ID</td><td>Link</td>
    <td>method</td>
    <td>from_tag</td>
    <td>to_tag</td>
    <td>callid</td>
    <td>sip_code</td>
    <td>sip_reason</td>
    <td>time</td>
    <td>time_attr</td>
    <td>time_exten</td>
</tr>
{% for object in object_list %}
<tr>
    <td>{{object.pk}}</td>
    <td><a href="{{object.get_absolute_url}}">{{object}}</a></td>
    <td>{{ object.method }}</td>
    <td>{{ object.from_tag }}</td>
    <td>{{ object.to_tag }}</td>
    <td>{{ object.callid }}</td>
    <td>{{ object.sip_code }}</td>
    <td>{{ object.sip_reason }}</td>
    <td>{{ object.time }}</td>
    <td>{{ object.time_attr }}</td>
    <td>{{ object.time_exten }}</td>
</tr>
{% endfor %}
</table><a class="btn btn-primary" href="{% url 'pyfb-kamailio:pyfb_kamailio_acc_create' %}">Create new Acc</a>
{% endblock %}
