# Generated by Django 2.1.5 on 2019-02-25 18:03

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('pyfb_kamailio', '0004_auto_20190225_1140'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='acc',
            options={'ordering': ('-time',)},
        ),
        migrations.AlterModelOptions(
            name='acccdr',
            options={'ordering': ('-start_time',)},
        ),
        migrations.AddField(
            model_name='acc',
            name='cseq',
            field=models.CharField(default='', help_text='cseq field', max_length=128),
        ),
        migrations.AddField(
            model_name='acc',
            name='from_domain',
            field=models.CharField(default='', help_text='FROM domain field', max_length=128),
        ),
        migrations.AddField(
            model_name='acc',
            name='from_user',
            field=models.CharField(default='', help_text='FROM user field', max_length=128),
        ),
        migrations.AddField(
            model_name='acc',
            name='ruri_domain',
            field=models.CharField(default='', help_text='RURI domain field', max_length=128),
        ),
        migrations.AddField(
            model_name='acc',
            name='ruri_user',
            field=models.CharField(default='', help_text='RURI user field', max_length=128),
        ),
        migrations.AddField(
            model_name='acc',
            name='src_ip',
            field=models.CharField(default='', help_text='source IP', max_length=128),
        ),
        migrations.AddField(
            model_name='acccdr',
            name='callee',
            field=models.CharField(default='', max_length=128),
        ),
        migrations.AddField(
            model_name='acccdr',
            name='caller',
            field=models.CharField(default='', max_length=128),
        ),
        migrations.AddField(
            model_name='acccdr',
            name='callid',
            field=models.CharField(default='', max_length=128),
        ),
        migrations.AddField(
            model_name='acccdr',
            name='company_id',
            field=models.IntegerField(default=0),
            preserve_default=False,
        ),
        migrations.AddField(
            model_name='acccdr',
            name='direction',
            field=models.CharField(default='', max_length=128),
        ),
    ]
