# Generated by Django 2.1.5 on 2020-03-21 15:51

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('pyfb_kamailio', '0009_auto_20190523_1647'),
    ]

    operations = [
        migrations.AddField(
            model_name='uacreg',
            name='socket',
            field=models.CharField(blank=True, default='', help_text='Used socket for sending out requests', max_length=128),
        ),
        migrations.AlterField(
            model_name='uacreg',
            name='auth_ha1',
            field=models.CharField(blank=True, default='', help_text='Hashed (HA1) auth password - to calculate : echo -n "username:realm:password" | md5sum', max_length=128),
        ),
        migrations.AlterField(
            model_name='uacreg',
            name='auth_password',
            field=models.CharField(blank=True, default='', help_text='Auth password', max_length=64),
        ),
        migrations.AlterField(
            model_name='uacreg',
            name='auth_proxy',
            field=models.CharField(blank=True, default='', help_text='Outbound proxy SIP address', max_length=255),
        ),
        migrations.AlterField(
            model_name='uacreg',
            name='expires',
            field=models.IntegerField(default=360, help_text='Expiration time in seconds, 0 means disabled'),
        ),
    ]
